@@ -24,7 +24,7 @@
   ## 1. setting arguments
   ##
   if(missing(messages))
-    messages.screen <- ifelse(is.null(getOption("geoR.messages")), TRUE, getOption("geoR.messages"))
+    messages.screen <- as.logical(ifelse(is.null(getOption("geoR.messages")), TRUE, getOption("geoR.messages")))
   else messages.screen <- messages
   if(missing(geodata))
     geodata <- list(coords = coords, data = data)
